==> byways-2.0.1.tgz: package/contents/byway/2047.md <==
---
template: byway.jade
id: "2047"
name: Mesa Falls Scenic Byway
distance: "28.7"
duration: Allow 1 hour.
description: The Mesa Falls Scenic Byway offers travelers a scenic drive along the Falls River and past Upper and Lower Mesa Falls.
contact: "**[Caribou-Targhee National Forest](http://www.fs.fed.us/r4/caribou-targhee/)**  \n 208-524-7500  \n\n"
path: "yt~kGpifgTH_dIJyaARap@Hso@DmaACmL[{Bs@kCu@kAs@u@mCkAk_@Dq@Gq@_@_DkC{kA}pAiB_BcBy@eBYyTE_^RgIg@mC]iDk@aBy@yBiCk@eAwBeHyA_Cu@a@mE_A}Bu@s@y@q@oAg@aBUaBiAmOi@sC}@{CaAkBo@y@cLwLu@kAeA_CiAgGsAgJImAIyFSsAg@mAm@s@eImHeFkDgBgBiA{A}E_IiByD}CcIuAgCiBwBsByAyAm@wBMqFz@iGmAwHgBiS_EsBm@cAk@_A_A_AyAi@sAc@_B_@gCIkA?sBHeAd@wCx@yCLkAFqACmAU{Aw@yC}AgFcAyB{@eAgCyBu@mAw@kBQy@iAaGs@sAiA_AsGeCmA{@y@cAi@mAyB{Is@_CeAsAsCaCgBmBoAkDo@{@mFyBaByA{@_BmBaFyBgDu@_Bm@qBu@m@uAg@}AQcBBi@HoH|DeGnHi@Ri@FqBO{@m@yCeEm@e@o@W_@Ce@FcAp@s@t@e@jAeEnRgBnGkAjCmIhPoB|Hc@hA_Az@oAp@mDfAiAx@iCjDgDzDs@rAgChKqBxDm@p@yBxA{o@zf@}BrC_A~A{F`MyCrEu@z@aCvAaBx@eErA{LpCsk@pOgVxIu@f@gAtAkBlE_@h@_AfAaB|@mj@|JuAf@iA|@sAdBe@x@k@xAeeA~cD}ZpaAe@lAgBrCmTd\\uDrEgsDrtCcBdAmAl@id@tL}NrD}WzDmB|@o@^aAfAcLtP}AdBof@fc@wA~@iAd@y@NeBJia@P_g@{CsB`@qG`DsDrA{]`JcDj@yAFm@A}AY{Ae@cAg@cBeAsGaFsAq@y@S_BMwKWqAMcA_@yEgCiCq@iQk@_NUcBRmBx@mA`AcBpB}@fBo@lBsNjh@o^lpA{AvEi@bAyAfBk@f@kXrM}ElC}AfAyC\\yAE}V_DwF_AyBq@mWuL]Ge@Pe@`@"
websites: 
  - url: "http://www.fs.usda.gov/ctnf"
    name: "Caribou-Targhee National Forest"
  - url: "http://www.fws.gov/refuges/profiles/index.cfm?id=53580"
    name: "Lake Umbagog National Wildlife Refuge-ME"
  - url: "http://www.idahobyways.gov/byways/mesa-falls.aspx"
    name: Mesa Falls Scenic Byway
  - url: "http://www.gorp.com/gorp/activity/byway/id_mesa.htm"
    name: "Mesa Falls Scenic Byway - GORP"
designations: 
  - National Forest Scenic Byway
  - Idaho State Scenic Byway
states: 
  - ID
ll: 
  - -111.44872299999997
  - 44.07133900000002
bounds: 
  - - -111.44872299999997
    - 44.071049000000016
  - - -111.28292099999999
    - 44.33972900000009

---

<p>Connecting with the Teton Scenic Byway at Ashton, the Mesa Falls
Scenic Byway takes you to two of the last undisturbed waterfalls of
consequence in the West. Main attractions, the Upper and Lower Mesa
Falls are the last major falls in Idaho that have not been used for
irrigation or hydroelectric projects. At 110 feet and 85 feet,
respectively, they offer equally spectacular views in a beautiful
forest setting. The upper waterfall has been developed with paths
and viewing areas and is easily accessible to all. At Lower Mesa
Falls, the Snake River is squeezed into a gorge that drops 65 feet.
The best view is from Grandview Campground and Overlook. The glassy
waters froth to mist in an even higher 11-story, 114-foot plunge.
Simply awesome!</p>

==> byways-2.3.2.tgz: package/contents/byway/2047.md <==
---
id: "2047"
name: Mesa Falls Scenic Byway
distance: "28.7"
duration: Allow 1 hour.
description: The Mesa Falls Scenic Byway offers travelers a scenic drive along the Falls River and past Upper and Lower Mesa Falls.
contact: "**[Caribou-Targhee National Forest](http://www.fs.fed.us/r4/caribou-targhee/)**  \n 208-524-7500  \n\n"
path: "yt~kGpifgTH_dIJyaARap@Hso@DmaACmL[{Bs@kCu@kAs@u@mCkAk_@Dq@Gq@_@_DkC{kA}pAiB_BcBy@eBYyTE_^RgIg@mC]iDk@aBy@yBiCk@eAwBeHyA_Cu@a@mE_A}Bu@s@y@q@oAg@aBUaBiAmOi@sC}@{CaAkBo@y@cLwLu@kAeA_CiAgGsAgJImAIyFSsAg@mAm@s@eImHeFkDgBgBiA{A}E_IiByD}CcIuAgCiBwBsByAyAm@wBMqFz@iGmAwHgBiS_EsBm@cAk@_A_A_AyAi@sAc@_B_@gCIkA?sBHeAd@wCx@yCLkAFqACmAU{Aw@yC}AgFcAyB{@eAgCyBu@mAw@kBQy@iAaGs@sAiA_AsGeCmA{@y@cAi@mAyB{Is@_CeAsAsCaCgBmBoAkDo@{@mFyBaByA{@_BmBaFyBgDu@_Bm@qBu@m@uAg@}AQcBBi@HoH|DeGnHi@Ri@FqBO{@m@yCeEm@e@o@W_@Ce@FcAp@s@t@e@jAeEnRgBnGkAjCmIhPoB|Hc@hA_Az@oAp@mDfAiAx@iCjDgDzDs@rAgChKqBxDm@p@yBxA{o@zf@}BrC_A~A{F`MyCrEu@z@aCvAaBx@eErA{LpCsk@pOgVxIu@f@gAtAkBlE_@h@_AfAaB|@mj@|JuAf@iA|@sAdBe@x@k@xAeeA~cD}ZpaAe@lAgBrCmTd\\uDrEgsDrtCcBdAmAl@id@tL}NrD}WzDmB|@o@^aAfAcLtP}AdBof@fc@wA~@iAd@y@NeBJia@P_g@{CsB`@qG`DsDrA{]`JcDj@yAFm@A}AY{Ae@cAg@cBeAsGaFsAq@y@S_BMwKWqAMcA_@yEgCiCq@iQk@_NUcBRmBx@mA`AcBpB}@fBo@lBsNjh@o^lpA{AvEi@bAyAfBk@f@kXrM}ElC}AfAyC\\yAE}V_DwF_AyBq@mWuL]Ge@Pe@`@"
websites:
  - url: "http://www.fs.usda.gov/ctnf"
    name: "Caribou-Targhee National Forest"
  - url: "http://www.fws.gov/refuges/profiles/index.cfm?id=53580"
    name: "Lake Umbagog National Wildlife Refuge-ME"
  - url: "http://www.idahobyways.gov/byways/mesa-falls.aspx"
    name: Mesa Falls Scenic Byway
  - url: "https://visitidaho.org/things-to-do/scenic-byways-backcountry-drives/mesa-falls-scenic-byway/"
    name: "Mesa Falls Scenic Byway"
designations:
  - National Forest Scenic Byway
  - Idaho State Scenic Byway
states:
  - ID
ll:
  - -111.44872299999997
  - 44.07133900000002
bounds:
  - - -111.44872299999997
    - 44.071049000000016
  - - -111.28292099999999
    - 44.33972900000009

---

<p>Connecting with the Teton Scenic Byway at Ashton, the Mesa Falls
Scenic Byway takes you to two of the last undisturbed waterfalls of
consequence in the West. Main attractions, the Upper and Lower Mesa
Falls are the last major falls in Idaho that have not been used for
irrigation or hydroelectric projects. At 110 feet and 85 feet,
respectively, they offer equally spectacular views in a beautiful
forest setting. The upper waterfall has been developed with paths
and viewing areas and is easily accessible to all. At Lower Mesa
Falls, the Snake River is squeezed into a gorge that drops 65 feet.
The best view is from Grandview Campground and Overlook. The glassy
waters froth to mist in an even higher 11-story, 114-foot plunge.
Simply awesome!</p>
